/**
 * Copyright (C) : INRIA - Domaine de Voluceau, Rocquencourt, B.P. 105, 
 * 78153 Le Chesnay Cedex - France 
 * 
 * contributor(s) : SARDES project - http://sardes.inrialpes.fr
 *
 * Contact : jakub.kornas@inrialpes.fr
 *
 * This software is a computer program whose purpose is to provide a framework
 * to build autonomic systems, following an architecture-based approach.
 *
 * This software is governed by the CeCILL-C license under French law and 
 * abiding by the rules of distribution of free software. You can use, modify
 * and/or redistribute the software under the terms of the CeCILL-C license as 
 * circulated by CEA, CNRS and INRIA at the following URL 
 * "http://www.cecill.info". 
 *
 * As a counterpart to the access to the source code and rights to copy, modify
 * and redistribute granted by the license, users are provided only with a 
 * limited warranty and the software's author, the holder of the economic 
 * rights, and the successive licensors have only limited liability. 
 *
 * In this respect, the user's attention is drawn to the risks associated with 
 * loading,  using,  modifying and/or developing or reproducing the software by 
 * the user in light of its specific status of free software, that may mean that
 * it is complicated to manipulate,  and  that  also therefore means  that it is
 * reserved for developers  and  experienced professionals having in-depth 
 * computer knowledge. Users are therefore encouraged to load and test the
 * software's suitability as regards their requirements in conditions enabling 
 * the security of their systems and/or data to be ensured and,  more generally,
 * to use and operate it in the same conditions as regards security. 
 *
 * The fact that you are presently reading this means that you have had 
 * knowledge of the CeCILL-C license and that you accept its terms.
 */

package org.objectweb.fractal.deployment.local.api;

import org.objectweb.fractal.api.Component;
import org.objectweb.fractal.api.Type;
import org.objectweb.fractal.api.factory.GenericFactory;
import org.objectweb.fractal.api.factory.InstantiationException;

/**
 * An extended {@link GenericFactory} to create {@link Component}s. It uses an
 * {@link Installer} component to install packages given their
 * {@link PackageDescription}s.
 * 
 * @author <a href="mailto:jakub.kornas@inrialpes.fr">Jakub Kornas
 * @uml.dependency supplier="org.objectweb.fractal.deployment.local.api.ComponentFactory"
 */
public interface GenericInstallingFactory extends GenericFactory {

	/**
	 * Creates a {@link Component} given its type, a description of its control
	 * part (membrane), description of its content part (implementation) and a
	 * description of a package in which all those can be found
	 * 
	 * @param type
	 *            The {@link Type} of the {@link Component} to be created
	 * @param controllerDesc
	 *            A description of the controller part of a component.
	 *            Implementation specific
	 * @param contentDesc
	 *            A description of the content part of a component.
	 *            Implementation specific
	 * @param packageDescription
	 *            A description of the package containing the code of this
	 *            component. Implementation specific
	 * 
	 */
	public Component newFcInstance(Type type, Object controllerDesc,
			Object contentDesc, PackageDescription packageDescription)
			throws InstantiationException;

	/**
	 * Undeploys a given {@link Component}
	 * 
	 * @param cmp
	 *            A {@link Component} to be undeployed
	 */
	public void undeployFcComponent(Component cmp);

	/**
	 * @return Returns the installer.
	 * @uml.property name="installer"
	 * @uml.associationEnd multiplicity="(1 1)"
	 *                     inverse="genericPackagedFactory:org.objectweb.fractal.deployment.local.api.Installer"
	 */
	// public Installer getInstaller();
	/**
	 * Setter of the property <tt>installer</tt>
	 * 
	 * @param installer
	 *            The installer to set.
	 * @uml.property name="installer"
	 */
	// public void setInstaller(Installer installer);
	/**
	 * Returns the {@link Loader} associated with a given {@Component}
	 * 
	 * @param A
	 *            {@link Component} for which we want to obtain the
	 *            {@link Loader}
	 * @return A {@link Loader} for a given {@link Component}
	 */
	public Loader getFcLoaderForComponent(Component cmp);

}
