/**
 * Copyright (C) : INRIA - Domaine de Voluceau, Rocquencourt, B.P. 105, 
 * 78153 Le Chesnay Cedex - France 
 * 
 * contributor(s) : SARDES project - http://sardes.inrialpes.fr
 *
 * Contact : jakub.kornas@inrialpes.fr
 *
 * This software is a computer program whose purpose is to provide a framework
 * to build autonomic systems, following an architecture-based approach.
 *
 * This software is governed by the CeCILL-C license under French law and 
 * abiding by the rules of distribution of free software. You can use, modify
 * and/or redistribute the software under the terms of the CeCILL-C license as 
 * circulated by CEA, CNRS and INRIA at the following URL 
 * "http://www.cecill.info". 
 *
 * As a counterpart to the access to the source code and rights to copy, modify
 * and redistribute granted by the license, users are provided only with a 
 * limited warranty and the software's author, the holder of the economic 
 * rights, and the successive licensors have only limited liability. 
 *
 * In this respect, the user's attention is drawn to the risks associated with 
 * loading,  using,  modifying and/or developing or reproducing the software by 
 * the user in light of its specific status of free software, that may mean that
 * it is complicated to manipulate,  and  that  also therefore means  that it is
 * reserved for developers  and  experienced professionals having in-depth 
 * computer knowledge. Users are therefore encouraged to load and test the
 * software's suitability as regards their requirements in conditions enabling 
 * the security of their systems and/or data to be ensured and,  more generally,
 * to use and operate it in the same conditions as regards security. 
 *
 * The fact that you are presently reading this means that you have had 
 * knowledge of the CeCILL-C license and that you accept its terms.
 */

package org.objectweb.fractal.deployment.local.api;

import org.objectweb.fractal.api.Component;

/**
 * An {@link Installer} is able to obtain code from a remote
 * {@link PackageRepository} and install it on a local machine on which it
 * executes. Once packages are installed by an {@link Installer}, their content
 * can be used to create (instantiate) {@link Component}s.
 * 
 * @author <a href="mailto:jakub.kornas@inrialpes.fr">Jakub Kornas
 */
public interface Installer {

	/**
	 * Installs a package given a {@link PackageDescription}
	 * 
	 * @param packageDescription
	 *            A description of the package to be installed. Implementation
	 *            specific
	 * @return A {@link LocallyInstalledPackage} object representing the given
	 *         package installed in the file system. Implementation specific
	 */
	public LocallyInstalledPackage install(PackageDescription packageDescription);

	/**
	 * Installs a package and marks it for later use. Marked packages can not be
	 * garbage collected
	 * 
	 * @param packageDescription
	 *            A description of the package to be installed. Implementation
	 *            specific
	 */
	public LocallyInstalledPackage installAndMark(
			PackageDescription packageDescription);

	/**
	 * Uninstalls a package. Even marked packages are uninstalled if this method
	 * is called
	 * 
	 * @param packageDescription
	 *            A description of the package to be uninstalled. Implementation
	 *            specific
	 */
	public void uninstall(LocallyInstalledPackage componentPackage)
			throws Exception;

	/**
	 * Lists all {@link LocallyInstalledPackage}s installed by this
	 * {@link Installer}
	 * 
	 * @return A table containing the installed packages
	 */
	public LocallyInstalledPackage[] getInstalledPackages();

	/**
	 * @return Returns the loaderFactory.
	 * @uml.property name="loaderFactory" default="new model.LoaderFactory()"
	 * @uml.associationEnd multiplicity="(1 1)"
	 *                     inverse="installer:model.LoaderFactory"
	 */
	// public LoaderFactory getLoaderFactory();
	/**
	 * Setter of the property <tt>loaderFactory</tt>
	 * 
	 * @param loaderFactory
	 *            The loaderFactory to set.
	 * @uml.property name="loaderFactory"
	 */
	// public void setLoaderFactory(LoaderFactory loaderFactory);
	/**
	 * @return Returns the packageRepository.
	 * @uml.property name="packageRepository"
	 * @uml.associationEnd multiplicity="(1 -1)"
	 *                     inverse="installer:model.PackageRepository"
	 */
	// public Collection getPackageRepository();
	/**
	 * Setter of the property <tt>packageRepository</tt>
	 * 
	 * @param packageRepository
	 *            The packageRepository to set.
	 * @uml.property name="packageRepository"
	 */
	// public void setPackageRepository(Collection packageRepository);
	// public void registerGarbageCollector(GarbageCollector gc);
}
