/**
 * Copyright (C) : INRIA - Domaine de Voluceau, Rocquencourt, B.P. 105, 
 * 78153 Le Chesnay Cedex - France 
 * 
 * contributor(s) : SARDES project - http://sardes.inrialpes.fr
 *
 * Contact : jakub.kornas@inrialpes.fr
 *
 * This software is a computer program whose purpose is to provide a framework
 * to build autonomic systems, following an architecture-based approach.
 *
 * This software is governed by the CeCILL-C license under French law and 
 * abiding by the rules of distribution of free software. You can use, modify
 * and/or redistribute the software under the terms of the CeCILL-C license as 
 * circulated by CEA, CNRS and INRIA at the following URL 
 * "http://www.cecill.info". 
 *
 * As a counterpart to the access to the source code and rights to copy, modify
 * and redistribute granted by the license, users are provided only with a 
 * limited warranty and the software's author, the holder of the economic 
 * rights, and the successive licensors have only limited liability. 
 *
 * In this respect, the user's attention is drawn to the risks associated with 
 * loading,  using,  modifying and/or developing or reproducing the software by 
 * the user in light of its specific status of free software, that may mean that
 * it is complicated to manipulate,  and  that  also therefore means  that it is
 * reserved for developers  and  experienced professionals having in-depth 
 * computer knowledge. Users are therefore encouraged to load and test the
 * software's suitability as regards their requirements in conditions enabling 
 * the security of their systems and/or data to be ensured and,  more generally,
 * to use and operate it in the same conditions as regards security. 
 *
 * The fact that you are presently reading this means that you have had 
 * knowledge of the CeCILL-C license and that you accept its terms.
 */

package org.objectweb.fractal.deployment.local.api;

import org.objectweb.fractal.api.Component;

/**
 * A {@link Component} interface to undeploy the component to which it belongs
 * 
 * @author <a href="mailto:jakub.kornas@inrialpes.fr">Jakub Kornas
 */
public interface UndeploymentController {
	/**
	 * Undeploys a {@link Component} to which this controller belongs. Depending
	 * on the implementation this method can:
	 * 
	 * <ul>
	 * <li>Check if this component is bound to other components and if so,
	 * unbind it, check if it has parents and if so, remove it from them and
	 * finally undeploy this component (remove it completely from the local
	 * machine, including the code). If any of this fails, throw an
	 * {@link UndeploymentException}.
	 * <li>Check if this component is bound to other components, if so, throw
	 * an UndeploymentException. If not, check if this component has parents and
	 * if so, throw an {@link UndeploymentException}.
	 * </ul>
	 * 
	 * @throws UndeploymentException
	 */
	public void undeploy() throws UndeploymentException;
}
